RewardUnlockedModalBuilder class

Inheritance

Constructors

RewardUnlockedModalBuilder({Key? key, required String title, String? subtitle, required Future<void> claimReward(), required double rewardAmount, Widget? child})
const

Properties

child Widget?
final
claimReward Future<void> Function()
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
final
rewardAmount double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
title String
final

Methods

build(BuildContext context) Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
view(BuildContext context) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

reveal({required String title, String? subtitle, required Future<void> claimReward(), required double rewardAmount, Widget? child}) Future<void>