Factory class

Constructors

Factory({required void onTncClick(String url), required void onMysteryBoxClicked(String cashbackId)})

Properties

hashCode int
The hash code for this object.
no setterinherited
onMysteryBoxClicked → void Function(String cashbackId)
final
onTncClick → void Function(String url)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

of(BuildContext context) Factory